import os
from collections import defaultdict
from ...imports import hashlib
from ...json_utils import safe_dump_to_json
from ...list_utils import make_list
from ...file_utils import get_files_and_dirs
